@@ -349,6 +349,21 @@ def get_component(dhurl, cookies, compname, compvariant, compversion, id_only, l
     return [-1, ""]
 
 
+def get_environment(dhurl, cookies, env):
+    name = ""
+    data = get_json(dhurl + "/dmadminweb/API/environment/?name=" + urllib.parse.quote(env), cookies)
+
+    if (data is None):
+        return [-1, ""]
+
+    if (data['success']):
+        envid = data['result']['id']
+        name = data['result']['name']
+
+        return [envid, name]
+
+    return [-1, ""]
+
 def get_component_name(dhurl, cookies, compid):
     name = ""
     data = get_json(dhurl + "/dmadminweb/API/component/" + str(compid) + "?idonly=Y", cookies)
@@ -357,7 +372,7 @@ def get_component_name(dhurl, cookies, compid):
         return name
 
     if (data['success']):
-        name = data['result']['name']
+        name = data['result']['domain'] + "." + data['result']['name']
     return name
 
 def get_component_attrs(dhurl, cookies, compid):
@@ -657,6 +672,13 @@ def update_compid_attrs(dhurl, cookies, compid, attrs):
         return [False, "Could not update attributes on '" + str(compid) + "'"]
     return [True, data, dhurl + "/dmadminweb/API/setvar/component/" + str(compid)]
 
+def update_envid_attrs(dhurl, cookies, envid, attrs):
+    payload = json.dumps(attrs)
+
+    data = post_json(dhurl + "/dmadminweb/API/setvar/environment/" + str(envid), payload, cookies)
+    if (not data):
+        return [False, "Could not update attributes on '" + str(envid) + "'"]
+    return [True, data, dhurl + "/dmadminweb/API/setvar/environment/" + str(envid)]
 
 def get_application(dhurl, cookies, appname, appversion, id_only):
     appversion = clean_name(appversion)
@@ -932,7 +954,7 @@ def log_deploy_application(dhurl, cookies, deploydata):
 
     return data
 
-def set_kvconfig(dhurl, cookies, kvconfig, appname, appversion, appautoinc, compname, compvariant, compversion, compautoinc, kind):
+def set_kvconfig(dhurl, cookies, kvconfig, appname, appversion, appautoinc, compname, compvariant, compversion, compautoinc, kind, env):
     if (is_empty(compvariant)):
         compvariant = ""
 
@@ -986,9 +1008,9 @@ def set_kvconfig(dhurl, cookies, kvconfig, appname, appversion, appautoinc, comp
 
         for attr in comp_attrs:
             key = list(attr.keys())[0]
+            value = attr[key]
             key = key.replace("\\\\", "/")
             key = key.replace("\\", "/")
-            value = attr[key]
             old_attrs.append(key + "=" + value)
 
     new_attrs = []
@@ -1012,36 +1034,60 @@ def set_kvconfig(dhurl, cookies, kvconfig, appname, appversion, appautoinc, comp
         data = update_compid_attrs(dhurl, cookies, compid, attrs)
 
         print("Attribute Update Done")
+    else:
+        data = get_component(dhurl, cookies, compname, compvariant, compversion, True, True)
+        compid = data[0]
 
-        if (is_not_empty(appname)):
+    if (is_not_empty(appname)):
 
-            if (is_not_empty(saveappver)):
-                appversion = saveappver
+        if (is_not_empty(saveappver)):
+            appversion = saveappver
 
-            if (is_empty(appversion)):
-                parts = appname.split(';')
-                if (len(parts) == 3):
-                    appname = parts[0] + ';' + parts[1]
-                    appversion = parts[2]
+        if (is_empty(appversion)):
+            parts = appname.split(';')
+            if (len(parts) == 3):
+                appname = parts[0] + ';' + parts[1]
+                appversion = parts[2]
 
-            if (is_empty(appversion)):
-                parts = appname.split(';')
-                if (len(parts) == 3):
-                    appname = parts[0] + ';' + parts[1]
-                    appversion = parts[2]
+        if (is_empty(appversion)):
+            parts = appname.split(';')
+            if (len(parts) == 3):
+                appname = parts[0] + ';' + parts[1]
+                appversion = parts[2]
 
-            if (is_empty(appversion)):
-                appversion = ""
+        if (is_empty(appversion)):
+            appversion = ""
 
-            print("Creating Application Version '" + str(appname) + "' '" + appversion + "'")
-            data = new_application(dhurl, cookies, appname, appversion, appautoinc, None)
+#            print("Creating Application Version '" + str(appname) + "' '" + appversion + "'")
+#            data = new_application(dhurl, cookies, appname, appversion, appautoinc, None)
+#            appid = data[0]
+#            print("Creation Done: " + get_application_name(dhurl, cookies, appid, True))
+#
+#            print("Assigning Component Version to Application Version " + str(appid))
+#
+#            data = add_compver_to_appver(dhurl, cookies, appid, compid)
+#            print("Assignment Done")
+
+        if (is_not_empty(env)):
+            data = get_environment(dhurl, cookies, env)
+            envid = data[0]
+
+            data = get_application(dhurl, cookies, appname, appversion, False)
+            
             appid = data[0]
-            print("Creation Done: " + get_application_name(dhurl, cookies, appid, True))
+            appname = data[1]
 
-            print("Assigning Component Version to Application Version " + str(appid))
+            config_component = get_component_name(dhurl, cookies, compid)
+            if ('.' in config_component):
+                config_component = config_component.split('.')[-1]
 
-            data = add_compver_to_appver(dhurl, cookies, appid, compid)
-            print("Assignment Done")
+            print(f'Updating environment {env} with config component {config_component}')
+
+            attrs = {}
+            attrs["Config Component"] = "<a href='javascript:void(0);' onclick=\"chgsel({t: 'components_tab', id: 'cv" + str(compid) + "', odl: '', tm: 'application_menu', name: '" + config_component + "'})\" >" + config_component + "</a>"
+            attrs["Last Deployed Application"] = "<a href='javascript:void(0);' onclick=\"chgsel({t: 'applications_tab', id: 'av" + str(appid) + "', odl: '', tm: 'application_menu', name: '" + appname + "'})\" >" + appname + "</a>"
+
+            update_envid_attrs(dhurl, cookies, envid, attrs)
     return
 
 # def update_versions(project, compname, compvariant, compversion):
